import { jsxs as _jsxs } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";
import { cloneElement, Children } from 'react';
import cx from 'classnames';
import AtomValidationText, { AtomValidationTextTypes } from '@s-ui/react-atom-validation-text';
import AtomLabel, { AtomLabelTypes } from '@s-ui/react-atom-label';
import AtomHelpText from '@s-ui/react-atom-help-text';
var BASE_CLASS = 'sui-MoleculeField';
var CLASS_INLINE = BASE_CLASS + "--inline";
var CLASS_AUTOHIDE = BASE_CLASS + "--autohide";
var CLASS_FULLWIDTH = BASE_CLASS + "--fullWidth";
var CLASS_INLINE_REVERSE = CLASS_INLINE + "-reverse";
var CLASS_NODE_LABEL_CONTAINER = BASE_CLASS + "-nodeLabelContainer";
var CLASS_INPUT_CONTAINER = BASE_CLASS + "-inputContainer";
var CLASS_LABEL_CONTAINER = BASE_CLASS + "-labelContainer";

var MoleculeLabel = function MoleculeLabel(_ref) {
  var label = _ref.label,
      nodeLabel = _ref.nodeLabel,
      typeValidationLabel = _ref.type,
      name = _ref.name,
      onClickLabel = _ref.onClickLabel;

  var innerLabel = function innerLabel() {
    if (label) {
      return /*#__PURE__*/_jsx(AtomLabel, {
        type: typeValidationLabel,
        name: name,
        text: label,
        onClick: onClickLabel
      });
    } else if (nodeLabel) {
      return /*#__PURE__*/cloneElement(nodeLabel, {
        type: typeValidationLabel,
        name: name,
        onClickLabel: onClickLabel
      });
    }
  };

  return /*#__PURE__*/_jsx("div", {
    className: CLASS_NODE_LABEL_CONTAINER,
    children: innerLabel()
  });
};

var MoleculeField = function MoleculeField(_ref2) {
  var inline = _ref2.inline,
      reverse = _ref2.reverse,
      errorText = _ref2.errorText,
      successText = _ref2.successText,
      alertText = _ref2.alertText,
      label = _ref2.label,
      nodeLabel = _ref2.nodeLabel,
      fullWidth = _ref2.fullWidth,
      useContrastLabel = _ref2.useContrastLabel,
      helpText = _ref2.helpText,
      name = _ref2.name,
      onClickLabel = _ref2.onClickLabel,
      onChangeFromProps = _ref2.onChange,
      children = _ref2.children,
      autoHideHelpText = _ref2.autoHideHelpText;
  var className = cx(BASE_CLASS, inline && CLASS_INLINE, inline && reverse && CLASS_INLINE_REVERSE, autoHideHelpText && CLASS_AUTOHIDE, fullWidth && CLASS_FULLWIDTH);
  var statusValidationText, typeValidationLabel, typeValidationText;
  var extendedChildren = Children.toArray(children).filter(Boolean).map(function (child, index) {
    return /*#__PURE__*/cloneElement(child, {
      onChange: onChangeFromProps
    });
  });

  if (useContrastLabel) {
    typeValidationLabel = AtomLabelTypes.CONTRAST;
  }

  if (errorText) {
    statusValidationText = errorText;
    typeValidationLabel = AtomLabelTypes.ERROR;
    typeValidationText = AtomValidationTextTypes.ERROR;
  }

  if (successText) {
    statusValidationText = successText;
    typeValidationLabel = AtomLabelTypes.SUCCESS;
    typeValidationText = AtomValidationTextTypes.SUCCESS;
  }

  if (alertText) {
    statusValidationText = alertText;
    typeValidationLabel = AtomLabelTypes.ALERT;
    typeValidationText = AtomValidationTextTypes.ALERT;
  }

  return /*#__PURE__*/_jsxs("div", {
    className: className,
    children: [(label || nodeLabel) && /*#__PURE__*/_jsxs("div", {
      className: CLASS_LABEL_CONTAINER,
      children: [inline && extendedChildren, /*#__PURE__*/_jsx(MoleculeLabel, {
        type: typeValidationLabel,
        name: name,
        label: label,
        nodeLabel: nodeLabel,
        onClick: onClickLabel
      })]
    }), /*#__PURE__*/_jsxs("div", {
      className: CLASS_INPUT_CONTAINER,
      children: [!inline && extendedChildren, typeValidationText && /*#__PURE__*/_jsx(AtomValidationText, {
        type: typeValidationText,
        text: statusValidationText
      }), helpText && /*#__PURE__*/_jsx(AtomHelpText, {
        text: helpText
      })]
    })]
  });
};

MoleculeField.displayName = 'MoleculeField';
export default MoleculeField;